==> umax-0.5.5.tar.gz: umax-0.5.5/umax-text.h <==
/* ----------------------------------------------------------------------- */

/* umax-text.h: textoutput of scanner driver for UMAX scanners.
 *
 * Version 0.5.5
 *
 */

/* ----------------------------------------------------------------------- */

#ifndef UMAX_TEXT_H
#define UMAX_TEXT_H

/* ==================================================================== */

static char *cbhs_str[]       = {"0-50","0-255",
                                 "0-255 autoexposure","reserved"};
static char *scanmode_str[]   = {"flatbed (FB)",
                                 "automatic document feeder (ADF)"};
static char *gamma_lines_str[]= {"reserved", \
                            "one line (grey), three pass (color) download" \
                            "reserved", \
                            "one line (grey), three lines (color) download" };
static char *color_sequence_str[]= {"R->G->B","R->B->G", \
                                    "G->B->R","G->R->B", \
                                    "B->R->G","B->G->R", \
                                    "reserved","all supported"};

static char *sense_str[] = {"NO SENSE",
                            "RECOVERED ERROR",
                            "NOT READY",
                            "MEDIUM ERROR:",
                            "HARDWARE ERROR:",
                            "ILLEGAL REQUEST:",
                            "UNIT ATTENTION:",
                            "DATA PROTECT",
                            "BLANK CHECK",
                            "VENDOR SPRECIFIC:",
			    "COPY ABORTED",
                            "ABORTED COMMAND",
                            "EQUAL",
                            "VOLUME OVERFLOW",
                            "MISCOMPARE",
                            "??? - SENSE 0FH" };

static char *scanner_error_str[] =
{"no error",      /* 0 */
 "CPU error",
 "reserved 2",
 "reserved 3",
 "ROM error",
 "reserved 5",
 "reserved 6",
 "reserved 7",
 "reserved 8",
 "reserved 9",
 "buffer error",        /* 10 */
 "system buffer error",
 "shading buffer error",
 "video buffer error",
 "stack buffer error",
 "control buffer error",
 "gamma buffer error",
 "reserved 17",
 "reserved 18",
 "reserved 19",
 "lamp error",          /* 20 */
 "dark error",
 "dim error",
 "light error",
 "lamp adjust control error (by darken)",
 "reserved 25",
 "reserved 26",
 "reserved 27",
 "reserved 28",
 "reserved 29",
 "calibration error",   /* 30 */
 "dc offset error",
 "gain error",
 "reserved 33",
 "reserved 34",
 "reserved 35",
 "reserved 36",
 "reserved 37",
 "reserved 38",
 "reserved 39",
 "scsi error",          /* 40 */
 "reserved 41",
 "asic error",
 "timer error",
 "ccd error",
 "reserved 45",
 "reserved 46",
 "reserved 47",
 "reserved 48",
 "reserved 49",
 "uta error",           /* 50 */
 "uta home or motor sensor error",
 "reserved 52",
 "reserved 53",
 "reserved 54",
 "reserved 55",
 "reserved 56",
 "reserved 57",
 "reserved 58",
 "reserved 59",
 "adf error",           /* 60 */
 "adf paper jam",
 "adf no paper",
 "adf cover open",
 "reserved 64",
 "reserved 65",
 "reserved 66",
 "reserved 67",
 "reserved 68",
 "reserved 69",
 "fb sensor error",     /* 70 */
 "fb home or motor sensor error",
 "fb filter or motor sensor error",
 "fb lens or motor sensor error"
 "first line position error (LER error, vertical)",
 "first pixel position error (SER error, horizontal)",
 "first pixel position error for lens 2 (SER2 error, horizontal)",
 "reserved 77",
 "reserved 78",
 "reserved 79",
 "reserved",      /* 80 */
 "reserved",
 "reserved",
 "reserved",
 "reserved",
 "reserved",
 "reserved",
 "reserved",
 "reserved",
 "reserved",
 "reserved",      /* 90 */
 "reserved",
 "reserved",
 "reserved",
 "reserved",
 "reserved",
 "reserved",
 "reserved",
 "reserved",
 "reserved"       /* 99 */
};



/* FIXME: spec seems incomplete at this point */
#endif /* UMAX_SCSIDEF_H */

==> umax-0.5.6.tar.gz: umax-0.5.6/umax-text.h <==
/* ----------------------------------------------------------------------- */

/* umax-text.h: header-file for textoutput of driver for UMAX scanners.
  
   (C) 1997 Oliver Rauch

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston,
   MA 02111-1307, USA.

 */

/* ----------------------------------------------------------------------- */

#ifndef UMAX_TEXT_H
#define UMAX_TEXT_H

/* ==================================================================== */

static char *cbhs_str[]       = {"0-50","0-255",
                                 "0-255 autoexposure","reserved"};

static char *scanmode_str[]   = {"flatbed (FB)",
                                 "automatic document feeder (ADF)"};

static char *gamma_lines_str[]= {"reserved",
                            "one line (grey), three pass (color) download",
                            "reserved",
                            "one line (grey), three lines (color) download" };

static char *color_sequence_str[]= {"R->G->B","R->B->G",
                                    "G->B->R","G->R->B",
                                    "B->R->G","B->G->R",
                                    "reserved","all supported"};

static char *sense_str[] = {"NO SENSE",
                            "RECOVERED ERROR",
                            "NOT READY",
                            "MEDIUM ERROR:",
                            "HARDWARE ERROR:",
                            "ILLEGAL REQUEST:",
                            "UNIT ATTENTION:",
                            "DATA PROTECT",
                            "BLANK CHECK",
                            "VENDOR SPRECIFIC:",
			    "COPY ABORTED",
                            "ABORTED COMMAND",
                            "EQUAL",
                            "VOLUME OVERFLOW",
                            "MISCOMPARE",
                            "??? - SENSE 0FH" };

static char *scanner_error_str[] =
{"no error",      /* 0 */
 "CPU error",
 "reserved 2",
 "reserved 3",
 "ROM error",
 "reserved 5",
 "reserved 6",
 "reserved 7",
 "reserved 8",
 "reserved 9",
 "buffer error",        /* 10 */
 "system buffer error",
 "shading buffer error",
 "video buffer error",
 "stack buffer error",
 "control buffer error",
 "gamma buffer error",
 "reserved 17",
 "reserved 18",
 "reserved 19",
 "lamp error",          /* 20 */
 "dark error",
 "dim error",
 "light error",
 "lamp adjust control error (by darken)",
 "reserved 25",
 "reserved 26",
 "reserved 27",
 "reserved 28",
 "reserved 29",
 "calibration error",   /* 30 */
 "dc offset error",
 "gain error",
 "reserved 33",
 "reserved 34",
 "reserved 35",
 "reserved 36",
 "reserved 37",
 "reserved 38",
 "reserved 39",
 "scsi error",          /* 40 */
 "reserved 41",
 "asic error",
 "timer error",
 "ccd error",
 "reserved 45",
 "reserved 46",
 "reserved 47",
 "reserved 48",
 "reserved 49",
 "uta error",           /* 50 */
 "uta home or motor sensor error",
 "reserved 52",
 "reserved 53",
 "reserved 54",
 "reserved 55",
 "reserved 56",
 "reserved 57",
 "reserved 58",
 "reserved 59",
 "adf error",           /* 60 */
 "adf paper jam",
 "adf no paper",
 "adf cover open",
 "reserved 64",
 "reserved 65",
 "reserved 66",
 "reserved 67",
 "reserved 68",
 "reserved 69",
 "fb sensor error",     /* 70 */
 "fb home or motor sensor error",
 "fb filter or motor sensor error",
 "fb lens or motor sensor error"
 "first line position error (LER error, vertical)",
 "first pixel position error (SER error, horizontal)",
 "first pixel position error for lens 2 (SER2 error, horizontal)",
 "reserved 77",
 "reserved 78",
 "reserved 79",
 "reserved",      /* 80 */
 "reserved",
 "reserved",
 "reserved",
 "reserved",
 "reserved",
 "reserved",
 "reserved",
 "reserved",
 "reserved",
 "reserved",      /* 90 */
 "reserved",
 "reserved",
 "reserved",
 "reserved",
 "reserved",
 "reserved",
 "reserved",
 "reserved",
 "reserved"       /* 99 */
};



/* FIXME: spec seems incomplete at this point */
#endif /* UMAX_SCSIDEF_H */
